==> qbs-1.2.1.src.zip: qbs-1.2.1/src/app/config/configmain.cpp <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the Qt Build Suite.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "configcommandlineparser.h"
#include "configcommandexecutor.h"
#include "../shared/qbssettings.h"

#include <logging/translator.h>
#include <tools/error.h>

#include <QCoreApplication>

#include <cstdlib>
#include <iostream>

using qbs::Internal::Tr;

int main(int argc, char *argv[])
{
    QCoreApplication app(argc, argv);
    ConfigCommandLineParser parser;
    try {
        parser.parse(app.arguments().mid(1));
        if (parser.helpRequested()) {
            std::cout << qPrintable(Tr::tr("This tool manages qbs settings.")) << std::endl;
            parser.printUsage();
            return EXIT_SUCCESS;
        }
        SettingsPtr settings = qbsSettings(parser.settingsDir());
        ConfigCommandExecutor(settings.data()).execute(parser.command());
    } catch (const qbs::ErrorInfo &e) {
        std::cerr << qPrintable(e.toString()) << std::endl;
        parser.printUsage();
        return EXIT_FAILURE;
    }
}

==> qbs-1.3.0.src.zip: qbs-1.3.0/src/app/config/configmain.cpp <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the Qt Build Suite.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "configcommandlineparser.h"
#include "configcommandexecutor.h"

#include <logging/translator.h>
#include <tools/error.h>
#include <tools/settings.h>

#include <QCoreApplication>

#include <cstdlib>
#include <iostream>

using qbs::Internal::Tr;
using qbs::Settings;

int main(int argc, char *argv[])
{
    QCoreApplication app(argc, argv);
    ConfigCommandLineParser parser;
    try {
        parser.parse(app.arguments().mid(1));
        if (parser.helpRequested()) {
            std::cout << qPrintable(Tr::tr("This tool manages qbs settings.")) << std::endl;
            parser.printUsage();
            return EXIT_SUCCESS;
        }
        Settings settings(parser.settingsDir());
        ConfigCommandExecutor(&settings).execute(parser.command());
    } catch (const qbs::ErrorInfo &e) {
        std::cerr << qPrintable(e.toString()) << std::endl;
        parser.printUsage();
        return EXIT_FAILURE;
    }
}
